@@ -1,10 +1,10 @@
-coxpls2.default <- function(Xplan,time,time2,event,type,origin,typeres="deviance", collapse, weighted, scaleX=TRUE, scaleY=TRUE, ncomp=min(7,ncol(Xplan)), validation = "CV", plot=FALSE, allres=FALSE,...) {
-if(scaleX){Xplan <- as.data.frame(scale(Xplan))} else {Xplan <- as.data.frame(Xplan)}
+coxpls2.default <- function(Xplan,time,time2,event,type,origin,typeres="deviance", collapse, weighted, scaleX=TRUE, scaleY=TRUE, nt=min(7,ncol(Xplan)), typeVC="none", plot=FALSE, allres=FALSE,sparse=FALSE,sparseStop=TRUE,...) {
+if(scaleX){Xplan <- scale(Xplan)}
 if((scaleY & missing(time2))){time <- scale(time)}
 try(attachNamespace("survival"),silent=TRUE)
 on.exit(try(unloadNamespace("survival"),silent=TRUE))
-library(pls)
-on.exit(try(detach(package:pls),silent=TRUE),add=TRUE)
+try(attachNamespace("plsRglm"),silent=TRUE)
+on.exit(try(unloadNamespace("plsRglm"),silent=TRUE))
 
 mf <- match.call(expand.dots = FALSE)
 m <- match(c("time", "time2", "event", "type", "origin"), names(mf), 0L)
@@ -13,14 +13,13 @@ mf[[1L]] <- as.name("Surv")
 YCsurv <- eval(mf, parent.frame())
 
 mf2 <- match.call(expand.dots = FALSE)
-m2 <- match(c("ncomp", "validation"), names(mf2), 0L)
+m2 <- match(c("nt","typeVC","sparse","sparseStop"), names(mf2), 0L)
 mf2 <- mf2[c(1L, m2)]
-mf2$formula <- as.formula(time~.)
-mf2$data <- Xplan
-mf2$method <- "oscorespls"
-mf2[[1L]] <- as.name("plsr")
+mf2$dataY <- time
+mf2$dataX <- Xplan
+mf2[[1L]] <- as.name("PLS_lm")
 pls2_mod <- eval(mf2, parent.frame())
-tt_pls2 <- data.frame(pls::scores(pls2_mod)[,])
+tt_pls2 <- data.frame(pls2_mod$tt)
 
 mf2b <- match.call(expand.dots = TRUE)
 m2b <- match(c(head(names(as.list(args(coxph))),-2),head(names(as.list(args(coxph.control))),-1)), names(mf2b), 0L)
